@@ -56,12 +56,11 @@
 ##' 
 ##' @example Rd_examples/Ex_makeCholBlock.R
 ##' 
-##' @author Johan Lindstrm and Adam Szpiro
+##' @author Johan Lindstrom and Adam Szpiro
 ##' 
 ##' @family basic linear algebra
 ##' @family block matrix functions
 ##' @export
-##' @useDynLib SpatioTemporal C_make_chol_block
 makeCholBlock <- function(mat, n.blocks=1,
                           block.sizes=rep(dim(mat)[1]/n.blocks,n.blocks)){
   ##special case for one block
@@ -71,7 +70,8 @@ makeCholBlock <- function(mat, n.blocks=1,
   ##ensure that block sizes are integer valued
   block.sizes <- round(block.sizes)
   ##call the c-function
-  tmp <- .Call(C_make_chol_block, as.integer(block.sizes), mat)
+  tmp <- .Call(C_make_chol_block, as.integer(block.sizes), mat,
+               PACKAGE="SpatioTemporal")
   ##check if matrix is pos.def
   if( tmp[1]==-1 ){
     stop("In 'makeCholBlock': Matrix not positive definite.")
@@ -81,7 +81,6 @@ makeCholBlock <- function(mat, n.blocks=1,
 
 ##' @rdname makeCholBlock
 ##' @export
-##' @useDynLib SpatioTemporal C_inv_chol_block
 invCholBlock <- function(R, n.blocks=1,
                          block.sizes=rep(dim(R)[1]/n.blocks,n.blocks)){
   ##special case for one block
@@ -92,7 +91,8 @@ invCholBlock <- function(R, n.blocks=1,
   block.sizes <- round(block.sizes)
   
   ##call the c-function, error checking in C-code.
-  .Call(C_inv_chol_block, as.integer(block.sizes), R)
+  .Call(C_inv_chol_block, as.integer(block.sizes), R,
+        PACKAGE="SpatioTemporal")
 }##function invCholBlock
 
 ##' @param B Vector or matrix containg the right hand side of the equations
@@ -101,7 +101,6 @@ invCholBlock <- function(R, n.blocks=1,
 ##'   Controls if we solve the equations system given by R*x = B or R'*x=B.
 ##' @rdname makeCholBlock
 ##' @export
-##' @useDynLib SpatioTemporal C_solve_tri_block
 solveTriBlock <- function(R, B, n.blocks=1,
                           block.sizes=rep(dim(R)[1]/n.blocks,n.blocks),
                           transpose=FALSE){
@@ -114,7 +113,7 @@ solveTriBlock <- function(R, B, n.blocks=1,
   }else{
     ##call the c-function, error checking in C-code.
     .Call(C_solve_tri_block, as.integer(block.sizes),
-          as.integer(transpose), R, B)
+          as.integer(transpose), R, B, PACKAGE="SpatioTemporal")
   }
 }##function solveTriBlock
 
@@ -134,17 +133,17 @@ solveTriBlock <- function(R, B, n.blocks=1,
 ##' 
 ##' @example Rd_examples/Ex_blockMult.R
 ##' 
-##' @author Johan Lindstrm
+##' @author Johan Lindstrom
 ##' @family basic linear algebra
 ##' @family block matrix functions
 ##' @export
-##' @useDynLib SpatioTemporal C_block_mult
 blockMult <- function(mat, X, n.blocks=1,
                        block.sizes=rep(dim(mat)[1]/n.blocks,n.blocks)){
   ##ensure that block sizes are integer valued
   block.sizes <- round(block.sizes)
   ##call the c-function, error checking in C-code.
-  .Call(C_block_mult, as.integer(block.sizes), mat, X)
+  .Call(C_block_mult, as.integer(block.sizes), mat, X,
+        PACKAGE="SpatioTemporal")
 }##function blockMult
 
 ##' Computes the sum of the logarithm of the diagonal elements in a matrix, or
@@ -158,32 +157,29 @@ blockMult <- function(mat, X, n.blocks=1,
 ##' 
 ##' @example Rd_examples/Ex_sumLogDiag.R
 ##' 
-##' @author Johan Lindstrm
+##' @author Johan Lindstrom
 ##' @family basic linear algebra
 ##' @export
-##' @useDynLib SpatioTemporal C_sum_log_diag
 sumLogDiag <- function(mat){
   ##call the c-function, error checking in C-code.
-  .Call(C_sum_log_diag, mat)
+  .Call(C_sum_log_diag, mat, PACKAGE="SpatioTemporal")
 }##function sumLogDiag
 
 ##' @rdname sumLogDiag
 ##' @param v A vector
 ##' @export
-##' @useDynLib SpatioTemporal C_sum_log
 sumLog <- function(v){
   ##call the c-function, error checking in C-code.
-  .Call(C_sum_log, v)
+  .Call(C_sum_log, v, PACKAGE="SpatioTemporal")
 }##function sumLog
 
 
 ##' @rdname dotProd
 ##' @export
-##' @useDynLib SpatioTemporal C_norm2
 norm2 <- function(v1){
   ##calculate sum of the squared elements of a vector (or matrix) (|x|^2)
   ##input vector and vector size
-  .Call(C_norm2, v1)
+  .Call(C_norm2, v1, PACKAGE="SpatioTemporal")
 }##function norm2
 
 ##' \code{dotProd} computes the inner (or dot/scalar) product between two
@@ -203,14 +199,13 @@ norm2 <- function(v1){
 ##' 
 ##' @example Rd_examples/Ex_dotProd.R
 ##' 
-##' @author Johan Lindstrm
+##' @author Johan Lindstrom
 ##' @family basic linear algebra
 ##' @export
-##' @useDynLib SpatioTemporal C_dotProd
 dotProd <- function(v1,v2){
   if(length(v1)!=length(v2)){
     warning("In 'dotProd': vectors of unequal length, truncating the longer vector")
   }
   ##no need to check dimensions
-  .Call(C_dotProd, v1, v2)
+  .Call(C_dotProd, v1, v2, PACKAGE="SpatioTemporal")
 }##function dotProd
